Doc command implementation - generate project documentation
Now uses Handlebars templates and embedded assets for maintainability and portability.
Doc command implementation - generate project documentation
Now uses Handlebars templates and embedded assets for maintainability and portability.