pub fn resolve_effective_cli_config() -> Result<EffectiveCliConfig, ConfigError>Expand description
Resolve the effective CLI/user config by merging global and local configs, then applying defaults.
pub fn resolve_effective_cli_config() -> Result<EffectiveCliConfig, ConfigError>Resolve the effective CLI/user config by merging global and local configs, then applying defaults.