pub fn resolve_hyper_data_dir() -> Result<PathBuf, ConfigError>Expand description
Resolve only the effective Hyper data directory from the shared user config.
pub fn resolve_hyper_data_dir() -> Result<PathBuf, ConfigError>Resolve only the effective Hyper data directory from the shared user config.