pub fn create_local_proto(
project_dir: &Path,
project_name: &str,
proto_dir: &str,
template: ProjectTemplateName,
echo_role: Option<EchoRole>,
) -> Result<()>Expand description
Generate a local.proto file with the given package name.
For the echo service role, uses the full EchoService definition so that
actr gen can produce EchoHandler / EchoServiceActor traits.
For the echo app role and other templates, generates an empty skeleton.